@@ -1,122 +1,94 @@
 package WG::API::Auth;
 
-use Moo;
-with 'WG::API::Base';
-
-use constant api_uri => '//api.worldoftanks.ru/';
-
+use 5.014;
+use strict;
+use warnings;
+use base qw/WG::API/;
+ 
 =head1 NAME
 
-WG::API::Auth  - Auth-module with using OpenID for work with WG PAPI
+WG::API::Auth - The great new WG::API::Auth!
 
 =head1 VERSION
 
-Version v0.8.8
+Version v0.02
 
 =cut
 
-our $VERSION = 'v0.8.8';
+our $VERSION = 'v0.02';
 
 =head1 SYNOPSIS
 
-This module implements the possibility of authorization, prolongate and logout from the center of development.
+Quick summary of what the module does.
+
+Perhaps a little code snippet.
 
     use WG::API;
 
-    my $response = WG::API->new( application_id => 'demo' )->auth()->login( nofollow => '1', redirect_uri => 'yoursite.com/response' );
-
-    my $redirect_uri = $response->{ 'location' };
+    my $foo = WG::API->login();
     ...
 
 =head1 METHODS
 
-=over 1
+=head2 AUTH
 
-=item B<login>
-
-Method authenticates user based on Wargaming.net ID (OpenID) which is used in World of Tanks, World of Tanks Blitz, World of Warplanes, and WarGag.ru. To log in, player must enter email and password used for creating account, or use a social network profile. Authentication is not available for iOS Game Center users in the following cases: the account is not linked to a social network account, or email and password are not specified in the profile.
-
-Information on authorization status is sent to URL specified in redirect_uri parameter.
-
-=back
+=head3 login
 
 =cut
 
-sub login {
-    my $self = shift;
+sub login { 
+    $_[0]->_request( 'post', 'auth/login', ['expires_at', 'redirect_uri', 'display', 'nofollow'], undef, $_[1] );
 
-    return $self->_request( 'get', 'wot/auth/login/', [ 'expires_at', 'redirect_uri', 'display', 'nofollow' ], undef, @_ );
-}
+    return $_[0]->status eq 'ok' ? $_[0]->response : undef;
+}  
 
-=over 1
-
-=item B<prolongate>
-
-Method generates new access_token based on the current token.
-
-This method is used when the player is still using the application but the current access_token is about to expire.
-
-=over 2
-
-=item I<required fields:>
-
-    access_token - Access token for the private data of a user's account; can be received via the authorization method; valid within a stated time period
-
-=back
-
-=back
+=head3 prolongate
 
 =cut
 
-sub prolongate {
-    my $self = shift;
+sub prolongate { $_[0]->_request( 'post', 'auth/prolongate', ['access_token', 'expires_at'], ['access_token'], $_[1] ) }
 
-    return $self->_request( 'post', 'wot/auth/prolongate/', [ 'access_token', 'expires_at' ], ['access_token'], @_ );
-}
-
-=over 1
-
-=item B<logout>
-
-Method deletes user's access_token.
-
-After this method is called, access_token becomes invalid.
-
-=over 2
-
-=item I<required fields:>
-
-    access_token - Access token for the private data of a user's account; can be received via the authorization method; valid within a stated time period
-
-=back
-
-=back
+=head3 logout
 
 =cut
 
-sub logout {
+sub logout { $_[0]->_request( 'post', 'auth/logout', ['access_token'], ['access_token'], $_[1] ) }
+
+sub _init {
     my $self = shift;
 
-    return $self->_request( 'post', 'wot/auth/logout/', ['access_token'], ['access_token'], @_ );
+    $self->{ 'api_uri' } = 'api.worldoftanks.ru/wot';
+    $self->SUPER::_init();
+
+    return $self;
 }
+=head1 AUTHOR
+
+Cyrill Novgorodcev, C<< <cynovg at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://gitlab.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-wg-api at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WG-API>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+
+
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc WG::API
+    perldoc WG::API::Auth
+
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: GitHub's request tracker (report bugs here)
+=item * RT: CPAN's request tracker (report bugs here)
 
-L<https://gitlab.com/cynovg/WG-API/issues>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WG-API>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -128,22 +100,14 @@ L<http://cpanratings.perl.org/d/WG-API>
 
 =item * Search CPAN
 
-L<https://metacpan.org/pod/WG::API>
+L<http://search.cpan.org/dist/WG-API/>
 
 =back
 
 
 =head1 ACKNOWLEDGEMENTS
 
-...
-
-=head1 SEE ALSO
-
-WG API Reference L<https://developers.wargaming.net/>
-
-=head1 AUTHOR
-
-Cyrill Novgorodcev , C<< <cynovg at cpan.org> >>
+=cut
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -188,4 +152,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1;    # End of WG::API::Auth
+1; # End of WG::API::Auth
