@@ -1,18 +1,21 @@
 package WG::API::Error;
 
-use Moo;
+use 5.014;
+use strict;
+use warnings;
 
 =head1 NAME
 
-WG::API::Error - module for work with API error 
+WG::API::Error - The great new WG::API::Error!
 
 =head1 VERSION
 
-Version v0.8.8
+Version v0.02
 
 =cut
 
-our $VERSION = 'v0.8.8';
+our $VERSION = 'v0.02';
+
 
 =head1 SYNOPSIS
 
@@ -26,133 +29,94 @@ Perhaps a little code snippet.
     ...
     say $wg_error->code;
 
+=head1 SUBROUTINES/METHODS
 
-=head1 CONSTRUCTOR
+=head2 CONSTRUCTOR
 
-=head2 new
+=head3 new
 
 Create new error object.
 
 =cut
 
-=head2 ATTRIBUTES
+sub new {
+    my $class = shift;
+    
+    my $self = {};
+    bless $self, ref( $class ) ? ref( $class ) : $class;
 
-=over 1
+    $self->_parse( @_ );
 
-=item I<code>
+    return $self;
+}
 
-Error code.
+=head2 METHODS
 
-=back
+=head3 code
+
+Return error code.
 
 =cut
 
-has code => (
-    is       => 'ro',
-    required => 1,
-);
+sub code { shift->{ 'code' } }
 
-=over 1
+=head3 message
 
-=item I<message>
-
-Error message.
-
-=back
+Return error message.
 
 =cut
 
-has message => (
-    is       => 'ro',
-    required => 1,
-);
+sub message { shift->{ 'message' } }
 
-=over 1
+=head3 field
 
-=item I<field>
-
-Error field.
-
-=back
+Return error field.
 
 =cut
 
-has field => (
-    is       => 'ro',
-    required => 1,
-);
+sub field { shift->{ 'field' } }
 
-=over 1
+=head3 value
 
-=item I<value>
-
-Error value.
-
-=back
+Return error value.
 
 =cut
 
-has value => (
-    is       => 'ro',
-    required => 1,
-);
+sub value { shift->{ 'value' } }
 
-=over 
+sub _parse {
+    my ( $self, $response ) = @_;
 
-=item I<raw>
+    $self->{ 'code' }    = $response->{ 'code' };
+    $self->{ 'message' } = $response->{ 'message' };
+    $self->{ 'field' }   = $response->{ 'field' };
+    $self->{ 'value' }   = $response->{ 'value' };
 
-RAW data from invalid response
+    return;
+}
 
-=back
+=head1 AUTHOR
 
-=cut
-
-has raw => ( is => 'ro', );
+Cyrill Novgorodcev, C<< <cynovg at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://gitlab.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
+Please report any bugs or feature requests to C<bug-wg-api-error at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WG-API-Error>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+
+
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc WG::API
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: GitHub's request tracker (report bugs here)
-
-L<https://gitlab.com/cynovg/WG-API/issues>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/WG-API>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/WG-API>
-
-=item * Search CPAN
-
-L<https://metacpan.org/pod/WG::API>
-
-=back
-
-
-=head1 ACKNOWLEDGEMENTS
-
-...
+    perldoc WG::API::Error
 
 =head1 SEE ALSO
 
-WG API Reference L<https://developers.wargaming.net/>
-
-=head1 AUTHOR
-
-Cyrill Novgorodcev , C<< <cynovg at cpan.org> >>
+    perldoc WG::API
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -197,4 +161,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1;    # End of WG::API::Error
+1; # End of WG::API::Error
